@@ -110,6 +110,34 @@ class IotvideoClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ControlDeviceData(self, request):
+        """根据设备产品ID、设备名称，设置控制设备的属性数据。
+
+        :param request: Request instance for ControlDeviceData.
+        :type request: :class:`tencentcloud.iotvideo.v20201215.models.ControlDeviceDataRequest`
+        :rtype: :class:`tencentcloud.iotvideo.v20201215.models.ControlDeviceDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ControlDeviceData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ControlDeviceDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateBatch(self, request):
         """创建批次
 
@@ -362,6 +390,62 @@ class IotvideoClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeBalance(self, request):
+        """查询账户余额
+
+        :param request: Request instance for DescribeBalance.
+        :type request: :class:`tencentcloud.iotvideo.v20201215.models.DescribeBalanceRequest`
+        :rtype: :class:`tencentcloud.iotvideo.v20201215.models.DescribeBalanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeBalance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeBalanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeBalanceTransactions(self, request):
+        """拉取账户流水
+
+        :param request: Request instance for DescribeBalanceTransactions.
+        :type request: :class:`tencentcloud.iotvideo.v20201215.models.DescribeBalanceTransactionsRequest`
+        :rtype: :class:`tencentcloud.iotvideo.v20201215.models.DescribeBalanceTransactionsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeBalanceTransactions", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeBalanceTransactionsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeBatch(self, request):
         """获取批次详情
 
@@ -1342,6 +1426,34 @@ class IotvideoClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def PublishMessage(self, request):
+        """本接口（PublishMessage）用于使用自定义透传协议进行设备远控
+
+        :param request: Request instance for PublishMessage.
+        :type request: :class:`tencentcloud.iotvideo.v20201215.models.PublishMessageRequest`
+        :rtype: :class:`tencentcloud.iotvideo.v20201215.models.PublishMessageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("PublishMessage", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.PublishMessageResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ResetCloudStorage(self, request):
         """重置云存服务
 
